==> img0ch-2.1.0.tar.bz2: img0ch/_template/type/t_form.cs <==
<?xml version="1.0" encoding="shift_jis"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN"
  "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">

<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja">
<head>
<title><?cs var:BBS_TITLE ?>̃Xbh쐬tH[</title>
<meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS" />
<meta http-equiv="Content-Script-Type" content="text/javascript" />
<meta http-equiv="Content-Style-Type" content="text/css" />
<meta name="generator" content="<?cs var:html_escape(VERSION ESCAPE) ?>" />
<link media="all" href="<?cs var:StaticURI ?>/tdiary/base.css?v=<?cs var:html_escape(SecuredVersion) ?>" rel="stylesheet" />
<link media="all" href="<?cs var:StaticURI ?>/tdiary/<?cs if:BBS_TYPE_THEME ?><?cs var:BBS_TYPE_THEME ?>/<?cs var:BBS_TYPE_THEME ?>.css<?cs else ?>default/default.css<?cs /if ?>?v=<?cs var:html_escape(SecuredVersion) ?>" rel="stylesheet" />
<!--meta.txto͕-->
<?cs var:META ?>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery/cookie.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript">
//<![CDATA[
$(function () {
    $("//input[@name='FROM']").val($.cookie("NAME"));
    $("//input[@name='mail']").val($.cookie("MAIL"));
    $("form").submit(function () {
        if ( !$("input[@name='subject']", this).val() ) {
            alert("TuWFNg܂");
            return false;
        }
        if ( !$("textarea[@name='MESSAGE']", this).val() ) {
            alert("{܂");
            return false;
        }
        $("//input[@type='submit']").attr({ "disabled": true });
        return true;
    });
});
//]]>
</script>
<style type="text/css">
/*
<![CDATA[
<!--nobanner-->
*/
a { color: <?cs var:BBS_LINK_COLOR ?>; }
a:active { color: <?cs var:BBS_ALINK_COLOR ?>; }
a:visited { color: <?cs var:BBS_VLINK_COLOR ?>; }
fieldset { border: 0px; }
img { border: 0px; }
.center { text-align:center !important;  }
.clear { clear: both !important; }
.icon-align { vertical-align: top; }
.image { border: none; float: left; }
.nomail { color: <?cs var:BBS_NAME_COLOR ?> }
.right { text-align: right !important; }
.thread_info {}
.res_body { margin-left: 40px; }
/* ]]> */
</style>
</head>
<body>

<div class="center" id="top">
<?cs if:BBS_TITLE_PICTURE ?>
 <?cs if:BBS_TITLE_LINK ?>
  <a href="<?cs var:BBS_TITLE_LINK ?>">
   <img src="<?cs var:BBS_TITLE_PICTURE ?>" alt="<?cs var:BBS_TITLE ?>̊Ŕ" />
  </a>
 <?cs else ?>
  <img src="<?cs var:BBS_TITLE_PICTURE ?>" alt="<?cs var:BBS_TITLE ?>̊Ŕ" />
 <?cs /if ?>
<?cs /if ?>
</div>

<!--[J[\-->
<div class="day" id="info">
 <h2><span class="title"><?cs var:BBS_SUBTITLE ?></span></h2>
 <div class="body">
  <div class="section">
   <?cs var:HEAD ?>
  </div>
  <!--
  <span class="center">
   <a href="../index.html" id="backTo">fꗗ</a>
  </span>
  -->
 </div>
</div>

<!--L\-->
<?cs if:Banner ?>
<hr class="sep" />
<div class="day" id="mainBanner">
 <h2><span class="title">m</span></h2>
 <div class="body">
  <div class="section">
   <?cs var:Banner ?>
  </div>
 </div>
</div>
<?cs /if ?>

<hr class="sep" />

<!--tH[\-->
<div class="day" id="thread_builder_form">
 <h2><span class="title">XbhVK쐬</span></h2>
 <div class="form">
  <form class="comment" method="post" action="<?cs var:CGIURI ?>/bbs.cgi" enctype="multipart/form-data">
   <div class="hidden_field">
    <input type="hidden" name="bbs" value="<?cs var:BBS ?>" />
    <input type="hidden" name="time" value="<?cs var:TimeStamp ?>" />
   </div>
   <div class="textarea">
    ^CgF<input type="text" name="subject" size="25" />
   </div>
   <div class="field name">
    OF<input type="text" name="FROM" size="19" />
   </div>
   <div class="field mail">
    E-mailF<input type="text" name="mail" size="19" />
   </div>
   <?cs if:UploadableFromRes ?>
    <div class="textarea">摜F<input type="file" name="file" size="74" /></div>
   <?cs /if ?>
   <div class="textarea">
    RgF<textarea rows="5" cols="64" name="MESSAGE"></textarea>
   </div>
   <div class="button">
    <input type="submit" name="submit" value="VKXbh쐬" />
   </div>
  </form>
 </div>
</div>

<hr class="sep" />

<div class="footer">
 <?cs var:FOOT ?>
</div>

</body>
</html>

==> img0ch-2.1.2.tar.bz2: img0ch/_template/type/t_form.cs <==
<?xml version="1.0" encoding="shift_jis"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN"
  "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">

<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja">
<head>
<title><?cs var:BBS_TITLE ?>̃Xbh쐬tH[</title>
<meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS" />
<meta http-equiv="Content-Script-Type" content="text/javascript" />
<meta http-equiv="Content-Style-Type" content="text/css" />
<meta name="generator" content="<?cs var:html_escape(VERSION ESCAPE) ?>" />
<link media="all" href="<?cs var:StaticURI ?>/tdiary/base.css?v=<?cs var:html_escape(SecuredVersion) ?>" rel="stylesheet" />
<link media="all" href="<?cs var:StaticURI ?>/tdiary/<?cs if:BBS_TYPE_THEME ?><?cs var:BBS_TYPE_THEME ?>/<?cs var:BBS_TYPE_THEME ?>.css<?cs else ?>default/default.css<?cs /if ?>?v=<?cs var:html_escape(SecuredVersion) ?>" rel="stylesheet" />
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery/cookie.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript">
//<![CDATA[
jQuery(function () {
    jQuery("//input[@name='FROM']").val(jQuery.cookie("NAME"));
    jQuery("//input[@name='mail']").val(jQuery.cookie("MAIL"));
    jQuery("form.comment").submit(function () {
        if ( !jQuery("input[@name='subject']", this).val() ) {
            alert("TuWFNg܂");
            return false;
        }
        if ( !jQuery("textarea[@name='MESSAGE']", this).val() ) {
            alert("{܂");
            return false;
        }
        jQuery("//input[@type='submit']").attr({ "disabled": true });
        return true;
    });
});
//]]>
</script>
<style type="text/css">
/*
<![CDATA[
<!--nobanner-->
*/
a { color: <?cs var:BBS_LINK_COLOR ?>; }
a:active { color: <?cs var:BBS_ALINK_COLOR ?>; }
a:visited { color: <?cs var:BBS_VLINK_COLOR ?>; }
fieldset { border: 0px; }
img { border: 0px; }
.center { text-align:center !important;  }
.clear { clear: both !important; }
.icon-align { vertical-align: top; }
.image { border: none; float: left; }
.nomail { color: <?cs var:BBS_NAME_COLOR ?> }
.right { text-align: right !important; }
.thread_info {}
.res_body { margin-left: 40px; }
/* ]]> */
</style>
<!--meta.txto͕-->
<?cs var:META ?>
</head>
<body>

<div class="center" id="top">
<?cs if:BBS_TITLE_PICTURE ?>
 <?cs if:BBS_TITLE_LINK ?>
  <a href="<?cs var:BBS_TITLE_LINK ?>">
   <img src="<?cs var:BBS_TITLE_PICTURE ?>" alt="<?cs var:BBS_TITLE ?>̊Ŕ" />
  </a>
 <?cs else ?>
  <img src="<?cs var:BBS_TITLE_PICTURE ?>" alt="<?cs var:BBS_TITLE ?>̊Ŕ" />
 <?cs /if ?>
<?cs /if ?>
</div>

<!--[J[\-->
<div class="day" id="info">
 <h2><span class="title"><?cs var:BBS_SUBTITLE ?></span></h2>
 <div class="body">
  <div class="section">
   <?cs var:HEAD ?>
  </div>
  <!--
  <span class="center">
   <a href="../index.html" id="backTo">fꗗ</a>
  </span>
  -->
 </div>
</div>

<!--L\-->
<?cs if:Banner ?>
<hr class="sep" />
<div class="day" id="mainBanner">
 <h2><span class="title">m</span></h2>
 <div class="body">
  <div class="section">
   <?cs var:Banner ?>
  </div>
 </div>
</div>
<?cs /if ?>

<hr class="sep" />

<!--tH[\-->
<div class="day" id="thread_builder_form">
 <h2><span class="title">XbhVK쐬</span></h2>
 <div class="form">
  <form class="comment" method="post" action="<?cs var:CGIURI ?>/bbs.cgi" enctype="multipart/form-data">
   <div class="hidden_field">
    <input type="hidden" name="bbs" value="<?cs var:BBS ?>" />
    <input type="hidden" name="time" value="<?cs var:TimeStamp ?>" />
   </div>
   <div class="textarea">
    ^CgF<input type="text" name="subject" size="25" />
   </div>
   <div class="field name">
    OF<input type="text" name="FROM" size="19" />
   </div>
   <div class="field mail">
    E-mailF<input type="text" name="mail" size="19" />
   </div>
   <?cs if:UploadableFromRes ?>
    <div class="textarea">摜F<input type="file" name="file" size="74" /></div>
   <?cs /if ?>
   <div class="textarea">
    RgF<textarea rows="5" cols="64" name="MESSAGE"></textarea>
   </div>
   <div class="button">
    <input type="submit" name="submit" value="VKXbh쐬" />
   </div>
  </form>
 </div>
</div>

<hr class="sep" />

<div class="footer">
 <?cs var:FOOT ?>
</div>

</body>
</html>
